@@ -5,13 +5,14 @@ use 5.12.0;
 use strict;
 use warnings;
 
+our $VERSION = '0.36'; # TRIAL VERSION
+
 use List::Util 'first';
 use Log::Log4perl ':easy';
 
 use Moo;
 with "WWW::SFDC::Role::SessionConsumer";
 
-
 has '+session',
   is => 'ro',
   required => 0;
@@ -22,22 +23,20 @@ has 'uri',
 
 sub _extractURL { return $_[1]->{serverUrl} }
 
+
 has 'TYPES',
   is => 'ro',
   lazy => 1,
   default => sub {
     my $self = shift;
-    my ($describe) = $self->session->Metadata->describeMetadata(
-          $self->session->apiVersion
-    );
     +{
       map {
         $_->{directoryName} => $_;
-      } @{$describe->{metadataObjects}}
+      } @{$self->session->Metadata->describeMetadata->{metadataObjects}}
     }
   };
 
-has 'subcomponents',
+has '_subcomponents',
   is => 'ro',
   lazy => 1,
   default => sub {
@@ -85,7 +84,7 @@ sub getDiskName {
 
 sub getName {
   my ($self, $type) = @_;
-  return $type if grep {/$type/} @{$self->subcomponents};
+  return $type if grep {/$type/} @{$self->_subcomponents};
   LOGDIE "$type is not a recognised type" unless $self->TYPES->{$type};
   return $self->TYPES->{$type}->{xmlName};
 }
@@ -93,7 +92,7 @@ sub getName {
 
 sub getSubcomponents {
   my $self = shift;
-  return @{$self->subcomponents};
+  return @{$self->_subcomponents};
 }
 
 1;
@@ -108,7 +107,31 @@ WWW::SFDC::Constants - Data about SFDC Metadata Components.
 
 =head1 VERSION
 
-version 0.26
+version 0.36
+
+=head1 SYNOPSIS
+
+Provides the methods required for translating on-disk file names and component
+names to forms that the metadata API recognises, and vice-versa.
+
+  WWW::SFDC::Constants->new(
+    session => $session
+  );
+
+OR
+
+  WWW::SFDC::Constants->new(
+    TYPES => $types
+  );
+
+=head1 ATTRIBUTES
+
+=head2 TYPES
+
+A hashref containing the result of the metadataObjects member of a
+describeMetadata result. If this is populated, Constants will not send any API
+calls, so setting this in the constructor with a cached version provides
+offline functionality. If you specify a session, this attribute is optional.
 
 =head1 METHODS
 
@@ -124,35 +147,13 @@ version 0.26
 
 =head2 getSubcomponents
 
-=head1 Metadata Types
-
-=head2 ending
-
-Stores the file ending for the metadata type, if there is one.
-
-NB that two of these values are UNKNOWN because I don't know what the value is.
-
-=head2 name
-
-Stores the metadata API name corresponding to the folder name on disk. For instance, the
-metadata name corresponding to the applications/ folder is CustomApplication, but the name
-corresponding to flows/ is Flow.
-
-=head2 meta
-
-Set if the component has associated -meta.xml files (nb not counting folder xml files).
-
-=head2 folders
-
-Set if the type occurs within folders.
-
 =head1 AUTHOR
 
-Alexander Brett <alexander.brett@sophos.com>
+Alexander Brett <alexander.brett@sophos.com> L<http://alexander-brett.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Sophos Limited.
+This software is Copyright (c) 2015 by Sophos Limited L<https://www.sophos.com/>.
 
 This is free software, licensed under:
 
