@@ -5,14 +5,18 @@ use 5.12.0;
 use strict;
 use warnings;
 
+our $VERSION = '0.36'; # TRIAL VERSION
+
 use Data::Dumper;
 use Log::Log4perl ':easy';
+use Method::Signatures;
 use SOAP::Lite;
 
+use WWW::SFDC::Metadata::DeployResult;
+
 use Moo;
 with "WWW::SFDC::Role::SessionConsumer";
 
-
 has 'uri',
   is => 'ro',
   default => "http://soap.sforce.com/2006/04/metadata";
@@ -22,9 +26,7 @@ sub _extractURL {
 }
 
 
-sub listMetadata {
-
-  my $self = shift; #remaining elements of @_ are queries;
+method listMetadata {
 
   INFO "Listing Metadata...\t";
 
@@ -33,7 +35,7 @@ sub listMetadata {
 
   # listMetadata can only handle 3 requests at a time, so we chunk them.
   while (my @items = splice @queryData, 0, 3) {
-    push @result, $$_{fileName} for $self->_call('listMetadata', @items);
+    push @result, $$_{fileName} for @{$self->_call('listMetadata', @items)->results};
   }
 
   return @result;
@@ -43,11 +45,9 @@ sub listMetadata {
 # Sets up an asynchronous metadata retrieval request and
 # returns just the id, for checking later. Accepts a manifest.
 
-sub _startRetrieval {
+method _startRetrieval ($manifest) {
   INFO "Starting retrieval";
 
-  my ($self, $manifest) = @_;
-
   # These maps basically preserve the structure passed in,
   # translating it to salesforce's special package.xml structure.
   my @queryData = map {
@@ -60,7 +60,7 @@ sub _startRetrieval {
     } keys %$manifest;
 
 
-  return ($self->_call(
+  return $self->_call(
     'retrieve',
     SOAP::Data->name(
       retrieveRequest => {
@@ -68,7 +68,7 @@ sub _startRetrieval {
       	apiVersion => $self->session->apiVersion(),
       	unpackaged => \SOAP::Data->value(@queryData)
       })
-   ) )[0]->{id};
+   )->result->{id};
 
 }
 
@@ -76,14 +76,12 @@ sub _startRetrieval {
 # undef unless there's something to give back, in which case it
 # returns the base64 encoded zip file from the response.
 
-sub _checkRetrieval {
-  my ($self, $id) = @_;
-  LOGDIE "No ID was passed in!" unless $id;
+method _checkRetrieval ($id) {
 
-  my ($result) = $self->_call(
+  my $result = $self->_call(
     'checkRetrieveStatus',
     SOAP::Data->name("asyncProcessId" => $id)
-   );
+   )->result;
 
   INFO "Status:" . $$result{status};
 
@@ -93,45 +91,44 @@ sub _checkRetrieval {
 }
 
 
-sub retrieveMetadata {
-
-  my ($self, $manifest) = @_;
-  LOGDIE "This method must be called with a manifest" unless $manifest;
+method retrieveMetadata ($manifest) {
 
   my $requestId = $self->_startRetrieval($manifest);
-
   my $result;
 
   do { $self->_sleep() } until $result = $self->_checkRetrieval($requestId);
 
   return $result;
+
 }
 
 
 #Check up on an async deployment request. Returns 1 when complete.
-sub _checkDeployment {
-  my ($self, $id) = @_;
-  LOGDIE "No ID was passed in" unless $id;
+method _checkDeployment ($id, $previous?) {
 
-  my ($result) = $self->_call(
-    'checkDeployStatus',
-    SOAP::Data->name("id" => $id),
-    SOAP::Data->name("includeDetails" => "true")
-   );
+  my $callResult = $self->_call(
+      'checkDeployStatus',
+      SOAP::Data->name("id" => $id),
+      SOAP::Data->name("includeDetails" => "true")
+    )->result;
 
-  INFO "Deployment status:\t".$$result{status};
-  return 1 if $$result{status} eq "Succeeded";
-  return if $$result{status} =~ /Queued|Pending|InProgress/;
-  # useful deployment error here please
-  LOGDIE "DEPLOYMENT FAILED: ".Dumper $result->{details}->{componentFailures}
-    if $result->{status} eq "Failed";
-  LOGDIE "Check Deploy had an unexpected result: ".Dumper $result;
+  my $result = WWW::SFDC::Metadata::DeployResult->new(
+    result => $callResult
+  );
+
+  if (scalar (my @errors = (
+    $result->componentFailuresSince($previous),
+    $result->testFailuresSince($previous)
+  ))) {
+    WARN Dumper \@errors;
+  }
+
+  return $result
 }
 
-sub deployMetadata {
-  my ($self, $zip, $deployOptions) = @_;
+method deployMetadata ($zip, $deployOptions?) {
 
-  my ($result) = $self->_call(
+  my $result = $self->_call(
     'deploy',
     SOAP::Data->name( zipfile => $zip),
     (
@@ -139,36 +136,39 @@ sub deployMetadata {
         ? SOAP::Data->name(DeployOptions=>$deployOptions)
         : ()
     )
-   );
+   )->result;
 
-  INFO "Deployment status:\t".$$result{state};
+  INFO "Deployment ID: $$result{id}";
+
+  my $returnValue;
 
   #do..until guarantees that sleep() executes at least once.
-  do {$self->_sleep()} until $self->_checkDeployment($$result{id});
-
-  return $$result{id};
+  $self->_sleep()
+    until (
+      $returnValue = $self->_checkDeployment($$result{id}, $returnValue)
+    )->complete;
 
+  return $returnValue;
 }
 
 
-sub deployRecentValidation {
-  my ($self, $id) = @_;
-
+method deployRecentValidation ($id) {
   chomp $id;
 
-  return $self->_call(
-    'deployRecentValidation',
-    SOAP::Data->name(validationID => $id)
-   );
+  return WWW::SFDC::Metadata::DeployResult->new(
+    result => $self->_call(
+      'deployRecentValidation',
+      SOAP::Data->name(validationID => $id)
+    )->result
+  );
 }
 
-sub describeMetadata {
-  my ($self) = @_;
 
+method describeMetadata {
   return $self->_call(
     'describeMetadata',
     SOAP::Data->name(apiVersion => $self->session->apiVersion)
-   );
+   )->result;
 }
 
 1;
@@ -183,7 +183,7 @@ WWW::SFDC::Metadata - Interface to the Salesforce.com Metadata API
 
 =head1 VERSION
 
-version 0.26
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -211,16 +211,18 @@ For more in-depth examples, see t/WWW/SFDC/Metadata.t
 
 =head1 METHODS
 
-=head2 listMetadata @queries
+=head2 listMetadata(@queries)
 
 Accepts a list of types and folders, such as
 
+$session->Metadata->listMetadata(
    {type => "CustomObject"},
    {type => "Report", folder => "FooReports"}
+);
 
 and generates a list of file names suitable for turning into a WWW::SFDC::Manifest.
 
-=head2 retrieveMetadata $manifest
+=head2 retrieveMetadata($manifest)
 
 Sets up a retrieval from then checks it until done. Returns the
 same data as checkRetrieval. Requires a manifest of the form:
@@ -231,19 +233,31 @@ same data as checkRetrieval. Requires a manifest of the form:
    "Profile" => ["*"]
   };
 
+This method handles starting the retrieval, and polls until it completes, then
+returns the a string which is the base64 encoded .zip file containing the
+data.
+
 =head2 deployMetadata $zipString, \%deployOptions
 
 Takes a base64 zip file and deploys it. Deploy options will be
 passed verbatim into the request; see the metadata developer
 guide for a description.
 
+Returns a WWW::SFDC::Metadata::DeployResult containing the result of the
+operation. You must manually check whether this succeeded!
+
 =head2 deployRecentValidation $id
 
 Calls deployRecentValidation with your successfully-validated deployment.
 
+=head2 describeMetadata
+
+Returns a describeMetadataResult hashref as specified by Salesforce.com.
+L<WWW::SFDC::Constants> consumes this object to provide utility methods.
+
 =head1 BUGS
 
-Please report any bugs or feature requests at L<https://github.com/alexander-brett/WWW-SFDC/issues>.
+Please report any bugs or feature requests at L<https://github.com/sophos/WWW-SFDC/issues>.
 
 =head1 SUPPORT
 
@@ -251,15 +265,15 @@ You can find documentation for this module with the perldoc command.
 
     perldoc WWW::SFDC::Metadata
 
-You can also look for information at L<https://github.com/alexander-brett/WWW-SFDC>
+You can also look for information at L<https://github.com/sophos/WWW-SFDC>
 
 =head1 AUTHOR
 
-Alexander Brett <alexander.brett@sophos.com>
+Alexander Brett <alexander.brett@sophos.com> L<http://alexander-brett.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Sophos Limited.
+This software is Copyright (c) 2015 by Sophos Limited L<https://www.sophos.com/>.
 
 This is free software, licensed under:
 
