@@ -5,45 +5,32 @@ use 5.12.0;
 use strict;
 use warnings;
 
+our $VERSION = '0.36'; # TRIAL VERSION
+
+use Data::Dumper;
 use List::NSect 'spart';
 use Log::Log4perl ':easy';
-use Moo::Role;
+use Method::Signatures;
 use Scalar::Util 'blessed';
 use SOAP::Lite;
 
-requires qw'';
+use Moo::Role;
+requires qw'_prepareSObjects';
 
 
-sub _query {
-  my ($self, $query) = @_;
-  return $self->_call(
-    'query',
-    SOAP::Data->name(queryString => $query),
-  );
-}
-
-sub _queryAll {
-  my ($self, $query) = @_;
-  return $self->_call(
-    'queryAll',
-    SOAP::Data->name(queryString => $query),
-  );
-}
-
-sub _queryMore {
-  my ($self, $locator) = @_;
+method _queryMore ($locator) {
   return $self->_call(
     'queryMore',
     SOAP::Data->name(queryLocator => $locator),
-  );
+  )->result;
 }
 
 # Extract the results from a $request. This handles the case
 # where there is only one result, as well as 0 or more than 1.
 # They require different handling because in the 1 case, you
 # can't handle it as an array
-sub _getQueryResults {
-  my ($self, $request) = @_;
+method _getQueryResults ($request) {
+  TRACE Dumper $request;
   return ref $request->{records} eq 'ARRAY'
     ? map {$self->_cleanUpSObject($_)} @{$request->{records}}
     : ( $self->_cleanUpSObject($request->{records}) );
@@ -51,13 +38,14 @@ sub _getQueryResults {
 
 # Unbless an SObject, and de-duplicate the ID field - SFDC
 # duplicates the ID, which is interpreted as an arrayref!
-sub _cleanUpSObject {
-  my ($self, $obj) = @_;
+method _cleanUpSObject ($obj) {
   return () unless $obj;
   my %copy = %$obj; # strip the class from $obj
-  $copy{Id} = $copy{Id}->[0] if ref $copy{Id} eq "ARRAY";
+  $copy{Id} = $copy{Id}->[0] if $copy{Id} and ref $copy{Id} eq "ARRAY";
+  delete $copy{Id} unless $copy{Id};
 
   while (my ($key, $entry) = each %copy) {
+    next unless blessed $entry;
     if (blessed $entry eq 'sObject') {
       $copy{$key} = $self->_cleanUpSObject($entry);
     } elsif (blessed $entry eq 'QueryResult') {
@@ -72,98 +60,105 @@ sub _cleanUpSObject {
   return \%copy;
 }
 
-# Given the output of _query() or _queryAll(), chain
-# together calls to _queryMore() and aggregate the results.
-sub _completeQuery {
-  my ($self, $request) = @_;
-  my @results = $self->_getQueryResults($request);
+# Chain together calls to _queryMore() and handle the results.
+method _completeQuery (
+  :$query!,
+  :$method!,
+  :$callback = sub {state @results; push @results, @_; return @results}
+) {
 
-  until ($request->{done} eq 'true') {
+  INFO "Executing SOQL query: $query";
+
+  my $result = $self->_call(
+    $method,
+    SOAP::Data->name(queryString => $query)
+  )->result;
+
+  my @results = $callback->($self->_getQueryResults($result));
+  until ($result->{done} eq 'true') {
     $self->_sleep();
-    $request = $self->_queryMore($request->{queryLocator});
-    push @results, $self->_getQueryResults($request);
+    $result = $self->_queryMore($result->{queryLocator});
+    @results = $callback->($self->_getQueryResults($result));
   }
 
   return @results;
 }
 
-sub query {
-  my ($self, $query) = @_;
-  INFO "Executing SOQL query: ".$query;
+method query ($params) {
   return $self->_completeQuery(
-    $self->_query($query)
+    ref $params
+      ? %$params
+      : (query => $params),
+    method => 'query'
   );
 }
 
-sub queryAll {
-  my ($self, $query) = @_;
+method queryAll ($params) {
   return $self->_completeQuery(
-    $self->_queryAll($query)
+    ref $params
+      ? %$params
+      : (query => $params),
+    method => 'queryAll'
   );
+
 }
 
 
-sub create {
-  my $self = shift;
-
+method create (@_) {
   return map {
-    $self->_call(
+    @{$self->_call(
       'create',
       $self->_prepareSObjects(@$_)
-    );
+    )->results};
   } spart 200, @_;
 }
 
 
-sub update {
-  my $self = shift;
+method update (@_) {
 
   TRACE "Objects for update" => \@_;
   INFO "Updating objects";
 
-  return $self->_call(
+  return @{$self->_call(
     'update',
     $self->_prepareSObjects(@_)
-   );
+   )->results};
 }
 
 
-sub delete {
-    my $self = shift;
+method delete (@_) {
 
     DEBUG "IDs for deletion" => \@_;
     INFO "Deleting objects";
 
-    return $self->_call(
+    return @{$self->_call(
         'delete',
         map {SOAP::Data->name('ids' => $_)} @_
-    );
+    )->results};
 }
 
 
-sub undelete {
-    my $self = shift;
+method undelete (@_) {
 
     DEBUG "IDs for undelete" => \@_;
     INFO "Deleting objects";
 
-    return $self->_call(
+    return @{$self->_call(
         'undelete',
         map {SOAP::Data->name('ids' => $_)} @_
-    );
+    )->results};
 }
 
 
-sub retrieve {
-    my $self = shift;
+method retrieve (@_) {
 
     DEBUG "IDs for retrieve" => \@_;
     INFO "Retrieving objects";
 
-    return $self->_call(
+    return @{$self->_call(
         'retrieve',
         map {SOAP::Data->name('ids' => $_)} @_
-    );
+    )->results};
 }
 
 1;
@@ -178,20 +173,34 @@ WWW::SFDC::Role::CRUD - Shared methods between partner and tooling APIs
 
 =head1 VERSION
 
-version 0.26
+version 0.36
+
+=head1 DESCRIPTION
+
+WWW::SFDC::Role::CRUD provides standard SObject manipulation methods which are
+shared between the Partner and Tooling APIs.
 
 =head1 METHODS
 
 =head2 query
 
-  say $_->{Id} for WWW::SFDC::Partner->instance()->query($queryString);
-
 If the query() API call is incomplete and returns a queryLocator, this
 library will continue calling queryMore() until there are no more records to
-recieve, at which point it will return the entire list.
+recieve, at which point it will return the entire list:
 
-As it stands, if you want the native API behaviour, you will need to use the
-internal methods _query and _queryMore.
+  say $_->{Id} for WWW::SFDC->new(...)->Partner->query($queryString);
+
+OR:
+
+Execute a callback for each batch returned as part of a query. Useful for
+reducing memory usage and increasing efficiency handling huge queries:
+
+  WWW::SFDC->new(...)->Partner->query({
+    query => $queryString,
+    callback => \&myMethod
+  });
+
+This will return the result of the last call to &myMethod.
 
 =head2 queryAll
 
@@ -199,9 +208,9 @@ This has the same additional behaviour as query().
 
 =head2 create
 
-  say "$$_{id}:\t$$_{success}" for WWW::SFDC::Partner->instance()->create(
-    {type => 'thing', Id => 'foo', Field__c => 'bar', Name => 'baz'}
-    {type => 'otherthing', Id => 'bam', Field__c => 'bas', Name => 'bat'}
+  say "$$_{id}:\t$$_{success}" for WWW::SFDC->new(...)->Partner->create(
+    {type => 'thing', Field__c => 'bar', Name => 'baz'}
+    {type => 'otherthing', Field__c => 'bas', Name => 'bat'}
   );
 
 Create chunks your SObjects into 200s before calling create(). This means that if
@@ -234,7 +243,8 @@ Retrieves SObjects by ID. Not to be confused with the metadata retrieve method.
 
 =head1 BUGS
 
-Please report any bugs or feature requests at L<https://github.com/alexander-brett/WWW-SFDC/issues>.
+Please report any bugs or feature requests at
+L<https://github.com/sophos/WWW-SFDC/issues>.
 
 =head1 SUPPORT
 
@@ -242,15 +252,15 @@ You can find documentation for this module with the perldoc command.
 
     perldoc WWW::SFDC::Role::CRUD
 
-You can also look for information at L<https://github.com/alexander-brett/WWW-SFDC>
+You can also look for information at L<https://github.com/sophos/WWW-SFDC>
 
 =head1 AUTHOR
 
-Alexander Brett <alexander.brett@sophos.com>
+Alexander Brett <alexander.brett@sophos.com> L<http://alexander-brett.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Sophos Limited.
+This software is Copyright (c) 2015 by Sophos Limited L<https://www.sophos.com/>.
 
 This is free software, licensed under:
 
