@@ -5,13 +5,14 @@ use 5.12.0;
 use strict;
 use warnings;
 
+our $VERSION = '0.36'; # TRIAL VERSION
+
 use Log::Log4perl ':easy';
 use Scalar::Util 'blessed';
 
 use Moo;
 with 'WWW::SFDC::Role::SessionConsumer', 'WWW::SFDC::Role::CRUD';
 
-
 has 'uri',
   is => 'ro',
   default => 'urn:tooling.soap.sforce.com';
@@ -20,7 +21,6 @@ sub _extractURL {
   return $_[1]->{serverUrl} =~ s{/u/}{/T/}r;
 }
 
-
 sub _prepareSObjects {
   my $self = shift;
   # prepares an array of objects for an update or insert call by converting
@@ -67,7 +67,7 @@ sub executeAnonymous {
     $options{debug} ? SOAP::Header->name('DebuggingHeader' => \SOAP::Data->name(
         debugLevel => 'DEBUGONLY'
       )) : (),
-   );
+   )->result;
 
   LOGDIE "ExecuteAnonymous failed to compile: " . $result->{compileProblem}
     if $result->{compiled} eq "false";
@@ -85,14 +85,14 @@ sub runTests {
   return $self->_call(
     'runTests',
     map {\SOAP::Data->name(classes => $_)} @names
-  );
+  )->result;
 }
 
 
 sub runTestsAsynchronous {
   my ($self, @ids) = @_;
 
-  return $self->_call('runTestsAsynchronous', join ",", @ids);
+  return $self->_call('runTestsAsynchronous', join ",", @ids)->result;
 }
 
 1;
@@ -107,39 +107,68 @@ WWW::SFDC::Tooling - Interface to the Salesforce.com Tooling API
 
 =head1 VERSION
 
-version 0.26
+version 0.36
 
 =head1 SYNOPSIS
 
-   my $result = SFDC::tooling->instance(creds => {
+   my $result = WWW::SFDC->new(
     username => $USER,
     password => $PASS,
     url => $URL
-   })->executeAnonymous("System.debug(1);");
+   )->Tooling->executeAnonymous("System.debug(1);");
 
 Note that $URL is the _login_ URL, not the Tooling API endpoint URL - which gets calculated internally.
 
-=head1 METHODS
+This module consumes L<WWW::SFDC::Role::CRUD>.
 
-=head2 create
+=head1 METHODS
 
 =head2 describeGlobal
 
+Unimplemented
+
 =head2 describeSObjects
 
+Unimplemented
+
 =head2 executeAnonymous
 
-    WWW::SFDC::Tooling->instance()->executeAnonymous("system.debug(1);")
+    $client->Tooling->executeAnonymous("system.debug(1);")
 
 =head2 runTests
 
-  SFDC::Tooling->instance()->runTests('name','name2');
+  $client->Tooling->runTests('name','name2');
+
+returns a RunTestResult hash which looks like:
+
+{
+  successes => [{
+      name => 'MyTest',
+      id => '...',
+      namespace => undef,
+      time => 123, #time in MS
+      methodName => 'something'
+    },
+    ...
+  ],
+  failures => [{...}]
+  totalTime => 1234,
+  numFailures => 3,
+  numTestsRun => 4,
+  codeCoverage => [
+    # HUGE LIST OF HUGH HASHREFS GOES HERE.
+  ]
+
+}
 
 =head2 runTestsAsynchronous
 
+Takes a list of IDs of test classes.
+Returns the ID of the enqueued test run.
+
 =head1 BUGS
 
-Please report any bugs or feature requests at L<https://github.com/alexander-brett/WWW-SFDC/issues>.
+Please report any bugs or feature requests at L<https://github.com/sophos/WWW-SFDC/issues>.
 
 =head1 SUPPORT
 
@@ -147,15 +176,15 @@ You can find documentation for this module with the perldoc command.
 
     perldoc WWW::SFDC::Tooling
 
-You can also look for information at L<https://github.com/alexander-brett/WWW-SFDC>
+You can also look for information at L<https://github.com/sophos/WWW-SFDC>
 
 =head1 AUTHOR
 
-Alexander Brett <alexander.brett@sophos.com>
+Alexander Brett <alexander.brett@sophos.com> L<http://alexander-brett.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Sophos Limited.
+This software is Copyright (c) 2015 by Sophos Limited L<https://www.sophos.com/>.
 
 This is free software, licensed under:
 
