@@ -5,6 +5,8 @@ use 5.12.0;
 use strict;
 use warnings;
 
+our $VERSION = '0.36'; # TRIAL VERSION
+
 use Data::Dumper;
 use File::Path qw(mkpath);
 use File::Spec::Functions qw(splitpath);
@@ -126,7 +128,7 @@ WWW::SFDC::Zip - Utilities for manipulating base64 encoded zip files.
 
 =head1 VERSION
 
-version 0.26
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -134,16 +136,15 @@ version 0.26
 
     makezip $srcDirectory, @listOfFiles;
 
-    unzip $destDirectory, $base64encodedzipfile, &unzipTimeChanges
+    unzip $destDirectory, $base64encodedzipfile, &unzipTimeChanges;
 
 =head1 FUNCTIONS
 
 =head2 unzip $destFolder, $dataString, $callback
 
-Takes a some base64 $data and turns it into a file tree, starting
-at $dest. It does this by turning unpackaged/ into $dest/ whilst
-unzipping, so the data needs to come from an above-defined retrieve
-request.
+Takes a some base64 $data and turns it into a file tree, starting at $dest. It
+does this by turning unpackaged/ into $dest/ whilst unzipping, so the data
+needs to come from an above-defined retrieve request.
 
 Whilst each file is in memory, this function calls:
 
@@ -163,7 +164,7 @@ Can export unzip and makezip.
 
 =head1 BUGS
 
-Please report any bugs or feature requests at L<https://github.com/alexander-brett/WWW-SFDC/issues>.
+Please report any bugs or feature requests at L<https://github.com/sophos/WWW-SFDC/issues>.
 
 =head1 SUPPORT
 
@@ -171,15 +172,15 @@ You can find documentation for this module with the perldoc command.
 
     perldoc WWW::SFDC::Zip
 
-You can also look for information at L<https://github.com/alexander-brett/WWW-SFDC>
+You can also look for information at L<https://github.com/sophos/WWW-SFDC>
 
 =head1 AUTHOR
 
-Alexander Brett <alexander.brett@sophos.com>
+Alexander Brett <alexander.brett@sophos.com> L<http://alexander-brett.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Sophos Limited.
+This software is Copyright (c) 2015 by Sophos Limited L<https://www.sophos.com/>.
 
 This is free software, licensed under:
 
